translate.storage.properties.Dialect

Package translate :: Package storage :: Module properties :: Class Dialect |
[hide private]
[frames] | no frames]

# Class Dialect

source code

Settings for the various behaviours in key=value files.

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
encode(cls, string) Encode the string | source code
find_delimiter(cls, line) Find the delimeter | source code
key_strip(cls, key) Strip uneeded characters from the key | source code
value_strip(cls, value) Strip uneeded characters from the value | source code

Class Variables | [hide private]
| name = `None` Parse an instance of this class from the start of the given string.
| default_encoding = `'iso-8859-1'`
| delimiters = `None` Parse an instance of this class from the start of the given string.
| pair_terminator = `u""`
| key_wrap_char = `u""`
| value_wrap_char = `u""`

Properties | [hide private]
Inherited from `object`: `__class__`